==> ech_0.1.0.tar.gz: ech/R/ech.R <==
#' \code{ech} package
#'
#' Caja de Herramientas para el procesamiento de la Encuesta Continua de Hogares de Uruguay
#'
#' See the README on
#' \href{https://github.com/calcita/ech/blob/master/README.md}{Github}
#'
#' @docType package
#' @name ech
NULL

## quiets concerns of R CMD check re: the .'s that appear in pipelines
if(getRversion() >= "2.15.1") utils::globalVariables(c(".",
                                                       "numero",
                                                       "var17",
                                                       "unidad",
                                                       "fecha",
                                                       "indice",
                                                       "yy",
                                                       "mm",
                                                       "dd",
                                                       "X1",
                                                       "ipc",
                                                       "dpto",
                                                       "deflator_m",
                                                       "deflator_i",
                                                       "deflator_r",
                                                       "deflator_gini",
                                                       "deflator",
                                                       "ht19",
                                                       "ysvl",
                                                       "y_pc",
                                                       "y_pc_d",
                                                       "rv_d",
                                                       "y_wrv_d",
                                                       "y_wrv_pc_d",
                                                       "deflate_r",
                                                       "y_wrv_pc_d_r",
                                                       "quintil",
                                                       "decil",
                                                       "d14",
                                                       "overcrowding",
                                                       "bathroom",
                                                       "rooms",
                                                       "roof_materials",
                                                       "wall_materials",
                                                       "floor_materials",
                                                       "water",
                                                       "running_water",
                                                       "sewerage",
                                                       "electricity",
                                                       'housing_deprivation_q',
                                                       'main_work',
                                                       'second_work',
                                                       'self_employment',
                                                       'labor_income',
                                                       'labor_income_h',
                                                       'mes',
                                                       'hours_per_month',
                                                       'housing_situation',
                                                       'overcrowding',
                                                       "housing_tenure",
                                                       "housing_conditions",
                                                       "primary_completion",
                                                       "lower_secondary_completion",
                                                       "upper_secondary_completion",
                                                       "tertiary_completion",
                                                       "branch_group_ciiu",
                                                       "branch_ciiu",
                                                       "hours_per_month",
                                                       "total_income_per_hour",
                                                       "link",
                                                       "integrated_poverty_measure",
                                                       "UBN_q",
                                                       "UBN",
                                                       "UBN_education",
                                                       "UBN_confort",
                                                       "UBN_electricity",
                                                       "UBN_sewerage",
                                                       "UBN_water",
                                                       "UBN_housing",
                                                       "cba",
                                                       "cbna",
                                                       "indigency_line",
                                                       "poverty_line",
                                                       "indigent",
                                                       "poor",
                                                       "cbt_lp",
                                                       "cba_li",
                                                       "cbna_r",
                                                       "cba_li",
                                                       "cbna_r",
                                                       "cbt_lp",
                                                       "estrato",
                                                       "pesoano",
                                                       "school_enrollment",
                                                       "pd",
                                                       "pea",
                                                       "pet",
                                                       "po",
                                                       "label",
                                                       "d9",
                                                       "aux"
                                                       ))

==> ech_0.1.3.tar.gz: ech/R/ech.R <==
#' \code{ech} package
#' @family utils
#' @description Toolbox for Downloading and Processing Microdata from the Continuous Household Survey of Uruguay (ECH)
#'
#' See the README on
#' \href{https://github.com/calcita/ech/blob/master/README.md}{Github}
#'
#' @docType package
#' @name ech
NULL

## quiets concerns of R CMD check re: the .'s that appear in pipelines
if(getRversion() >= "2.15.1") utils::globalVariables(c(".",
                                                       "numero",
                                                       "var17",
                                                       "unidad",
                                                       "fecha",
                                                       "indice",
                                                       "yy",
                                                       "mm",
                                                       "dd",
                                                       "X1",
                                                       "ipc",
                                                       "dpto",
                                                       "deflator_m",
                                                       "deflator_i",
                                                       "deflator_r",
                                                       "deflator_gini",
                                                       "deflator",
                                                       "ht19",
                                                       "ysvl",
                                                       "y_pc",
                                                       "y_pc_d",
                                                       "rv_d",
                                                       "y_wrv_d",
                                                       "y_wrv_pc_d",
                                                       "deflate_r",
                                                       "y_wrv_pc_d_r",
                                                       "quintil",
                                                       "decil",
                                                       "d14",
                                                       "overcrowding",
                                                       "bathroom",
                                                       "rooms",
                                                       "roof_materials",
                                                       "wall_materials",
                                                       "floor_materials",
                                                       "water",
                                                       "running_water",
                                                       "sewerage",
                                                       "electricity",
                                                       'housing_deprivation_q',
                                                       'main_work',
                                                       'second_work',
                                                       'self_employment',
                                                       'labor_income',
                                                       'labor_income_h',
                                                       'mes',
                                                       'hours_per_month',
                                                       'housing_situation',
                                                       'overcrowding',
                                                       "housing_tenure",
                                                       "housing_conditions",
                                                       "primary_completion",
                                                       "lower_secondary_completion",
                                                       "upper_secondary_completion",
                                                       "tertiary_completion",
                                                       "branch_group_ciiu",
                                                       "branch_ciiu",
                                                       "hours_per_month",
                                                       "total_income_per_hour",
                                                       "link",
                                                       "integrated_poverty_measure",
                                                       "UBN_q",
                                                       "UBN",
                                                       "UBN_education",
                                                       "UBN_confort",
                                                       "UBN_electricity",
                                                       "UBN_sewerage",
                                                       "UBN_water",
                                                       "UBN_housing",
                                                       "cba",
                                                       "cbna",
                                                       "indigency_line",
                                                       "poverty_line",
                                                       "indigent",
                                                       "poor",
                                                       "cbt_lp",
                                                       "cba_li",
                                                       "cbna_r",
                                                       "cba_li",
                                                       "cbna_r",
                                                       "cbt_lp",
                                                       "estrato",
                                                       "pesoano",
                                                       "school_enrollment",
                                                       "pd",
                                                       "pea",
                                                       "pet",
                                                       "po",
                                                       "label",
                                                       "d9",
                                                       "aux",
                                                       "e201_1b",
                                                       "e201_1c",
                                                       "e201_1d",
                                                       "e51_4_a",
                                                       "e51_4_b",
                                                       "mes_y_ano",
                                                       "no_rel",
                                                       "sex_householder",
                                                       'everything'
                                                       ))
